- :class:`linear_model.BayesianRidge` and :class:`linear_model.ARDRegression` now
  center test features during :meth:`predict` to correctly compute predictive variance.
  By :user:`Danilo Silva <danilo-silva-ufsc>`.
